@@ -293,6 +293,12 @@ class OpenAssessmentBlock(MessageMixin,
         help="The id of the selected teamset.",
     )
 
+    show_rubric_during_response = Boolean(
+        default=False,
+        scope=Scope.settings,
+        help="Should the rubric be visible to learners in the response section?"
+    )
+
     @property
     def course_id(self):
         return str(self.xmodule_runtime.course_id)  # pylint: disable=no-member
@@ -822,6 +828,7 @@ class OpenAssessmentBlock(MessageMixin,
         block.group_access = config['group_access']
         block.teams_enabled = config['teams_enabled']
         block.selected_teamset_id = config['selected_teamset_id']
+        block.show_rubric_during_response = config['show_rubric_during_response']
         return block
 
     @property
